@@ -18,7 +18,7 @@ if __name__ == '__main__':
     site_group = "${template_group_name}"
     pam_user = os.getenv('PAM_USER')
 
-    cmd_list = ['bash -c \'id %s | grep "%s"  2> /dev/null\'' % (pam_user, site_group)]
+    cmd_list = ['bash -c \'id %s | grep "\(%s\)"  2> /dev/null\'' % (pam_user, site_group)]
     if CONF_MAP['UADM_USE_CENTRIFY']:
         cmd_list.append('bash -c \'adquery group %s -m 2> /dev/null | grep "%s"\'' % (site_group, pam_user))
 
