@@ -21,7 +21,6 @@ import sys
 
 from uadm.uadmcore import *
 
-#if __name__ == "__main__":
 def run(args = []):
     send_report(u"The computer has rebooted.", subject_prefix = "INFO")
 
@@ -46,3 +45,5 @@ def run(args = []):
 
     exec_cmd_list(cmd_list)
 
+if __name__ == "__main__":
+    run(sys.argv)
