@@ -19,6 +19,7 @@ If you have many scripts you can customize the CONF_MAP with a file in
 """
 
 import sys
+import os
 from os import path
 import socket
 import subprocess
@@ -229,6 +230,10 @@ def l(init=None):
         l_instance['l'] = init
     return l_instance['l']
 
+def get_rel_path(filename):
+    fn = os.path.join(os.path.dirname(__file__), filename)
+    return fn
+
 HOST_INFO = get_host_info()
 
 #Configuration map
@@ -244,6 +249,11 @@ CONF_MAP = {
     "UADM_REPORT_ON_SUCCESS" : False,
     "UADM_DISABLE_MAIL" : False,
     "UADM_ENABLED" : True,
+    'UADM_DOCROOT' : "/var/www",
+    'UADM_APACHE_VHOST_DIR' : "/etc/apache2/sites-available",
+    'UADM_LOGROTATE_DIR' : "/etc/logrotate.d",
+    'UADM_AUTO_MOUNT_DIR' : "/usr/local/bin/auto_mount_www",
+    "UADM_USE_CENTRIFY": False,
 }
 
 l_instance = {'l':''}
